Index: trunk/wb/framework/class.frontend.php
===================================================================
--- trunk/wb/framework/class.frontend.php	(revision 231)
+++ trunk/wb/framework/class.frontend.php	(revision 232)
@@ -250,8 +250,8 @@
 	}
 	
 	function page_link($link){
-		// Check for :// in the link (used in URL's)
-		if(strstr($link, '://') == '') {
+		// Check for :// in the link (used in URL's) as well as mailto:
+		if(strstr($link, '://') == '' AND substr($link, 0, 7) != 'mailto:') {
 			return WB_URL.PAGES_DIRECTORY.$link.PAGE_EXTENSION;
 		} else {
 			return $link;
Index: trunk/wb/framework/functions.php
===================================================================
--- trunk/wb/framework/functions.php	(revision 231)
+++ trunk/wb/framework/functions.php	(revision 232)
@@ -405,8 +405,8 @@
 // Function to work out a page link
 if(!function_exists('page_link')) {
 	function page_link($link) {
-		// Check for :// in the link (used in URL's)
-		if(strstr($link, '://') == '') {
+		// Check for :// in the link (used in URL's) as well as mailto:
+		if(strstr($link, '://') == '' AND substr($link, 0, 7) != 'mailto:') {
 			return WB_URL.PAGES_DIRECTORY.$link.PAGE_EXTENSION;
 		} else {
 			return $link;
